@@ -9,6 +9,7 @@ use std::time::Duration as StdDuration;
 use std::time::Instant as StdInstant;
 
 pub struct PlayClock {
+    start: StdInstant,
     last: StdInstant,
     pub delta: StdDuration,
 }
@@ -16,6 +17,7 @@ pub struct PlayClock {
 impl Default for PlayClock {
     fn default() -> Self {
         Self {
+            start: StdInstant::now(),
             last: StdInstant::now(),
             delta: StdDuration::new(0, 0),
         }
@@ -27,7 +29,16 @@ impl PlayClock {
         self.delta = now.duration_since(self.last);
         self.last = now;
     }
+    pub fn last_seconds(&self) -> f32 {
+        self.last.duration_since(self.start).as_secs_f32()
+    }
     pub fn delta_seconds(&self) -> f32 {
         self.delta.as_secs_f32()
     }
+    pub fn last_seconds_f64(&self) -> f64 {
+        self.last.duration_since(self.start).as_secs_f64()
+    }
+    pub fn delta_seconds_f64(&self) -> f64 {
+        self.delta.as_secs_f64()
+    }
 }
